# -*- coding: utf-8 -*-

from django.core.mail import send_mail
from django.http.response import Http404
from django.views.generic import CreateView
from django.views.generic.base import TemplateView
from django.contrib import messages
from qcf.models import Email
from qcf.forms import EmailForm
from qcf.conf import SAVE_TO_DB, RECIPIENTS_LIST, EMAIL_SENT_MESSAGE, REDIRECT_URL


class OkPageView(TemplateView):
    template_name = "qcf/ok.html"


class AddPostView(CreateView):
    model = Email
    form_class = EmailForm
    
    def form_valid(self, form, **kwargs):
        if self.request.method == "POST":
            obj = form.save(commit=False)
            obj.email = form.cleaned_data['email']
            obj.subject = form.cleaned_data['subject']
            obj.content = form.cleaned_data['content']
            formated_request = ''
            for key in self.request.META.keys():
                formated_request += str(key)+' : '+str(self.request.META[key])+'\n'
            obj.request = formated_request
            #~ send mail
            send_mail(obj.subject, obj.content, obj.email, RECIPIENTS_LIST)
            messages.info(self.request, EMAIL_SENT_MESSAGE)
        else: 
            raise Http404
        if SAVE_TO_DB == True:
            return super(AddPostView, self).form_valid(form)
        else:
            return
        
    def get_template_names(self):
        return ['qcf/email_form.html']
            
    def get_success_url(self):
        return REDIRECT_URL


class AddPostRestView(AddPostView):
    
    def get_template_names(self):
        return ['qcf/rest_form.html']
    
    


# -*- coding: utf-8 -*-

from django.contrib import admin
from qcf.models import Email
from qcf.forms import EmailAdminForm


@admin.register(Email)
class EmailAdmin(admin.ModelAdmin):
    form = EmailAdminForm
    search_fields = ('message', 'subject')
    date_hierarchy = 'created'
    list_display = ('email', 'subject', 'created')
    
    def get_readonly_fields(self, request, obj=None):
        readonly_fields = ('created', 'email', 'subject', 'content')
        if request.user.is_superuser:
            readonly_fields += ('request',)
        return readonly_fields


# -*- coding: utf-8 -*-

from django.utils.translation import ugettext_lazy as _
from django.apps import AppConfig


class QcfConfig(AppConfig):
    name = "qcf"
    verbose_name = _(u"Contact form")
    
    def ready(self):
        pass


# -*- coding: utf-8 -*-

from django.db import models
from django.utils.translation import ugettext_lazy as _


class Email(models.Model):
    email = models.EmailField(verbose_name=_(u'Email'))
    subject = models.CharField(max_length=255, verbose_name=_(u'Subject'))
    content = models.TextField(verbose_name=_(u'Message'))
    # meta info
    created = models.DateTimeField(auto_now_add=True, verbose_name=_(u'Date posted'))
    request = models.TextField()
    
    class Meta:
        verbose_name=_(u'Email')
        verbose_name_plural = _(u'Emails')
        ordering = ('-created',)

    def __unicode__(self):
        return unicode(self.email+' : '+self.subject)


# -*- coding: utf-8 -*-
# Generated by Django 1.10.2 on 2016-10-30 10:38
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Email',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('email', models.EmailField(max_length=254, verbose_name='Email')),
                ('subject', models.CharField(max_length=255, verbose_name='Subject')),
                ('content', models.TextField(verbose_name='Message')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Date posted')),
                ('request', models.TextField()),
            ],
            options={
                'ordering': ('-created',),
                'verbose_name': 'Email',
                'verbose_name_plural': 'Emails',
            },
        ),
    ]



# -*- coding: utf-8 -*-

from django import forms
from qcf.models import Email


class EmailForm(forms.ModelForm):
    # honeypot
    qcf = forms.CharField()
    qcf.label = ''
    qcf.required = False
    
    class Meta:
        model = Email
        fields = ['email', 'subject', 'content']
        widgets = {
            'content': forms.Textarea(attrs={'cols': 100, 'rows': 8, 'style':'width:100% !important;max-width:100% !important;'}),
            }
        
      
class EmailAdminForm(forms.ModelForm):
    class Meta:
        model = Email
        fields = ['email', 'subject', 'content']





# -*- coding: utf-8 -*-

from django.conf.urls import url
from qcf.views import AddPostView, AddPostRestView, OkPageView


urlpatterns = [
    url(r'^rest/$', AddPostRestView.as_view(), name="contact-rest"),
    url(r'^ok/$', OkPageView.as_view(), name="contact-ok"),
    url(r'^', AddPostView.as_view(), name="contact-post"),
    ]


# -*- coding: utf-8 -*-

from django.conf import settings
from django.utils.translation import ugettext_lazy as _
from django.core.urlresolvers import reverse_lazy


SAVE_TO_DB = getattr(settings, 'QCF_SAVE_TO_DB', True)

RECIPIENTS_LIST = getattr(settings, 'QCF_RECIPIENTS_LIST', [settings.DEFAULT_FROM_EMAIL])

EMAIL_SENT_MESSAGE = getattr(settings, 'QCF_EMAIL_SENT_MESSAGE', _(u'Your message has been sent'))

REDIRECT_URL = getattr(settings, 'QCF_REDIRECT_URL', reverse_lazy("contact-ok"))